
dic = {
"aback":"පස්සට",
"aback":"පසුපසට",
"aback":"පුදුමයට",
"aback":"විස්මයට",
"abacus":"ඇබකසය",
"abacus	":"ගණක චතුරස්‍රය",
"abacus	":"ගණක රාමුව",
"abacus	":"බෝල රාමුව",
"abaft":"නැවක පසු භාගයෙහි",
"abaft":"පස්සෙන්",
"abaft":"අවරට",
"abandon":"අත්හරිනවා",
"abandon":"අතරමං කරනවා",
"abandon":"ප්‍රතික්ෂේප කරනවා",
"abandon":"පිටුපානවා",
"abandon":"වර්ජනය කරනවා"

}
